pub struct Diagnostic { /* private fields */ }Expand description
A struct representing a diagnostic to emit to the end-user as an error.
Implementations
Sourceimpl Diagnostic
impl Diagnostic
Sourcepub fn error<T: Into<String>>(text: T) -> Diagnostic
pub fn error<T: Into<String>>(text: T) -> Diagnostic
Generate a Diagnostic from an informational message with no Span
Sourcepub fn span_error<T: Into<String>>(span: Span, text: T) -> Diagnostic
pub fn span_error<T: Into<String>>(span: Span, text: T) -> Diagnostic
Generate a Diagnostic from a Span and an informational message
Sourcepub fn spanned_error<T: Into<String>>(
node: &dyn ToTokens,
text: T,
) -> Diagnostic
pub fn spanned_error<T: Into<String>>( node: &dyn ToTokens, text: T, ) -> Diagnostic
Generate a Diagnostic from the span of any tokenizable object and a message
Sourcepub fn from_vec(diagnostics: Vec<Diagnostic>) -> BindgenResult<()>
pub fn from_vec(diagnostics: Vec<Diagnostic>) -> BindgenResult<()>
Attempt to generate a Diagnostic from a vector of other Diagnostic instances.
If the Vec is empty, returns Ok(()), otherwise returns the new Diagnostic